@@ -33,10 +33,11 @@
  */
 /* copyright --> */
 #include "AsyncNameResolver.h"
-#include "util.h"
-#include "A2STR.h"
+
 #include <cstring>
 
+#include "A2STR.h"
+
 namespace aria2 {
 
 #ifdef HAVE_LIBCARES1_5
@@ -47,63 +48,67 @@ void callback(void* arg, int status, int timeouts, struct hostent* host)
 {
   AsyncNameResolver* resolverPtr = reinterpret_cast<AsyncNameResolver*>(arg);
   if(status != ARES_SUCCESS) {
-#ifdef HAVE_LIBCARES
-    resolverPtr->error = ares_strerror(status);
-#else
-    resolverPtr->error = ares_strerror(status, 0);
-#endif // HAVE_LIBCARES
-    resolverPtr->status = AsyncNameResolver::STATUS_ERROR;
+    resolverPtr->error_ = ares_strerror(status);
+    resolverPtr->status_ = AsyncNameResolver::STATUS_ERROR;
     return;
   }
   for(char** ap = host->h_addr_list; *ap; ++ap) {
-    struct in_addr addr;
-    memcpy(&addr, *ap, sizeof(in_addr));
-    resolverPtr->_resolvedAddresses.push_back(inet_ntoa(addr));
+    char addrstring[INET6_ADDRSTRLEN];
+    const char* dst =
+      inet_ntop(host->h_addrtype, *ap, addrstring, sizeof(addrstring));
+    if(dst) {
+      resolverPtr->resolvedAddresses_.push_back(dst);
+    }
+  }
+  if(resolverPtr->resolvedAddresses_.empty()) {
+    resolverPtr->error_ = "inet_ntop failed";
+    resolverPtr->status_ = AsyncNameResolver::STATUS_ERROR;
+  } else {
+    resolverPtr->status_ = AsyncNameResolver::STATUS_SUCCESS;
   }
-  resolverPtr->status = AsyncNameResolver::STATUS_SUCCESS;
 }
 
-AsyncNameResolver::AsyncNameResolver():
-  status(STATUS_READY)
+AsyncNameResolver::AsyncNameResolver(int family):
+  status_(STATUS_READY),
+  family_(family)
 {
   // TODO evaluate return value
-  ares_init(&channel);
+  ares_init(&channel_);
 }
 
 AsyncNameResolver::~AsyncNameResolver()
 {
-  ares_destroy(channel);
+  ares_destroy(channel_);
 }
 
 void AsyncNameResolver::resolve(const std::string& name)
 {
-  _hostname = name;
-  status = STATUS_QUERYING;
-  ares_gethostbyname(channel, name.c_str(), AF_INET, callback, this);
+  hostname_ = name;
+  status_ = STATUS_QUERYING;
+  ares_gethostbyname(channel_, name.c_str(), family_, callback, this);
 }
 
 int AsyncNameResolver::getFds(fd_set* rfdsPtr, fd_set* wfdsPtr) const
 {
-  return ares_fds(channel, rfdsPtr, wfdsPtr);
+  return ares_fds(channel_, rfdsPtr, wfdsPtr);
 }
 
 void AsyncNameResolver::process(fd_set* rfdsPtr, fd_set* wfdsPtr)
 {
-  ares_process(channel, rfdsPtr, wfdsPtr);
+  ares_process(channel_, rfdsPtr, wfdsPtr);
 }
 
 #ifdef HAVE_LIBCARES
 
 int AsyncNameResolver::getsock(sock_t* sockets) const
 {
-  // TODO cast to int* might cause problem with Windows SOCKET?
-  return ares_getsock(channel, reinterpret_cast<int*>(sockets),
+  return ares_getsock(channel_, reinterpret_cast<ares_socket_t*>(sockets),
                       ARES_GETSOCK_MAXNUM);
 }
 
 void AsyncNameResolver::process(ares_socket_t readfd, ares_socket_t writefd)
 {
-  ares_process_fd(channel, readfd, writefd);
+  ares_process_fd(channel_, readfd, writefd);
 }
 
 #endif // HAVE_LIBCARES
@@ -115,12 +120,12 @@ bool AsyncNameResolver::operator==(const AsyncNameResolver& resolver) const
 
 void AsyncNameResolver::reset()
 {
-  _hostname = A2STR::NIL;
-  _resolvedAddresses.clear();
-  status = STATUS_READY;
-  ares_destroy(channel);
+  hostname_ = A2STR::NIL;
+  resolvedAddresses_.clear();
+  status_ = STATUS_READY;
+  ares_destroy(channel_);
   // TODO evaluate return value
-  ares_init(&channel);
+  ares_init(&channel_);
 }
 
 } // namespace aria2
