@@ -59,6 +59,10 @@
 #include "array_fun.h"
 #include "PieceStatMan.h"
 #include "wallclock.h"
+#include "bitfield.h"
+#ifdef ENABLE_BITTORRENT
+# include "bittorrent_helper.h"
+#endif // ENABLE_BITTORRENT
 
 namespace aria2 {
 
@@ -68,6 +72,7 @@ DefaultPieceStorage::DefaultPieceStorage
   bitfieldMan_(new BitfieldMan(downloadContext->getPieceLength(),
                                downloadContext->getTotalLength())),
   diskWriterFactory_(new DefaultDiskWriterFactory()),
+  endGame_(false),
   endGamePieceNum_(END_GAME_PIECE_NUM),
   logger_(LogFactory::getInstance()),
   option_(option),
@@ -79,34 +84,6 @@ DefaultPieceStorage::~DefaultPieceStorage() {
   delete bitfieldMan_;
 }
 
-bool DefaultPieceStorage::isEndGame()
-{
-  return bitfieldMan_->countMissingBlock() <= endGamePieceNum_;
-}
-
-bool DefaultPieceStorage::getMissingPieceIndex(size_t& index,
-                                               const unsigned char* bitfield,
-                                               size_t length)
-{
-  const size_t mislen = bitfieldMan_->getBitfieldLength();
-  array_ptr<unsigned char> misbitfield(new unsigned char[mislen]);
-  bool r;
-  if(isEndGame()) {
-    r = bitfieldMan_->getAllMissingIndexes(misbitfield, mislen,
-                                           bitfield, length);
-  } else {
-    r = bitfieldMan_->getAllMissingUnusedIndexes(misbitfield, mislen,
-                                                 bitfield, length);
-  }
-  if(r) {
-    // We assume indexes is sorted using comparator less.
-    return
-      pieceSelector_->select(index, misbitfield,bitfieldMan_->countBlock());
-  } else {
-    return false;
-  }
-}
-
 SharedHandle<Piece> DefaultPieceStorage::checkOutPiece(size_t index)
 {
   bitfieldMan_->setUseBit(index);
@@ -173,23 +150,6 @@ SharedHandle<Piece> DefaultPieceStorage::findUsedPiece(size_t index) const
   }
 }
 
-SharedHandle<Piece> DefaultPieceStorage::getMissingPiece
-(const unsigned char* bitfield, size_t length)
-{
-  size_t index;
-  if(getMissingPieceIndex(index, bitfield, length)) {
-    return checkOutPiece(index);
-  } else {
-    return SharedHandle<Piece>();
-  }
-}
-
-SharedHandle<Piece> DefaultPieceStorage::getMissingPiece
-(const BitfieldMan& bitfield)
-{
-  return getMissingPiece(bitfield.getBitfield(), bitfield.getBitfieldLength());
-}
-
 #ifdef ENABLE_BITTORRENT
 
 bool DefaultPieceStorage::hasMissingPiece(const SharedHandle<Peer>& peer)
@@ -198,10 +158,58 @@ bool DefaultPieceStorage::hasMissingPiece(const SharedHandle<Peer>& peer)
                                        peer->getBitfieldLength());
 }
 
-SharedHandle<Piece>
-DefaultPieceStorage::getMissingPiece(const SharedHandle<Peer>& peer)
+void DefaultPieceStorage::getMissingPiece
+(std::vector<SharedHandle<Piece> >& pieces,
+ size_t minMissingBlocks,
+ const unsigned char* bitfield,
+ size_t length)
 {
-  return getMissingPiece(peer->getBitfield(), peer->getBitfieldLength());
+  const size_t mislen = bitfieldMan_->getBitfieldLength();
+  array_ptr<unsigned char> misbitfield(new unsigned char[mislen]);
+  size_t blocks = bitfieldMan_->countBlock();
+  size_t misBlock = 0;
+  if(isEndGame()) {
+    bool r = bitfieldMan_->getAllMissingIndexes
+      (misbitfield, mislen, bitfield, length);
+    if(!r) {
+      return;
+    }
+    std::vector<size_t> indexes;
+    for(size_t i = 0; i < blocks; ++i) {
+      if(bitfield::test(misbitfield, blocks, i)) {
+        indexes.push_back(i);
+      }
+    }
+    std::random_shuffle(indexes.begin(), indexes.end());
+    for(std::vector<size_t>::const_iterator i = indexes.begin(),
+          eoi = indexes.end(); i != eoi && misBlock < minMissingBlocks; ++i) {
+      pieces.push_back(checkOutPiece(*i));
+      misBlock += pieces.back()->countMissingBlock();
+    }
+  } else {
+    bool r = bitfieldMan_->getAllMissingUnusedIndexes
+      (misbitfield, mislen, bitfield, length);
+    if(!r) {
+      return;
+    }
+    while(misBlock < minMissingBlocks) {
+      size_t index;
+      if(pieceSelector_->select(index, misbitfield, blocks)) {
+        pieces.push_back(checkOutPiece(index));
+        bitfield::flipBit(misbitfield, blocks, index);
+        misBlock += pieces.back()->countMissingBlock();
+      } else {
+        break;
+      }
+    }
+  }
+}
+
+static void unsetExcludedIndexes(BitfieldMan& bitfield,
+                                 const std::vector<size_t>& excludedIndexes)
+{
+  std::for_each(excludedIndexes.begin(), excludedIndexes.end(),
+                std::bind1st(std::mem_fun(&BitfieldMan::unsetBit), &bitfield));
 }
 
 void DefaultPieceStorage::createFastIndexBitfield
@@ -216,47 +224,107 @@ void DefaultPieceStorage::createFastIndexBitfield
   }
 }
 
-SharedHandle<Piece> DefaultPieceStorage::getMissingFastPiece
-(const SharedHandle<Peer>& peer)
+void DefaultPieceStorage::getMissingPiece
+(std::vector<SharedHandle<Piece> >& pieces,
+ size_t minMissingBlocks,
+ const SharedHandle<Peer>& peer)
 {
-  if(peer->isFastExtensionEnabled() && peer->countPeerAllowedIndexSet() > 0) {
-    BitfieldMan tempBitfield(bitfieldMan_->getBlockLength(),
-                             bitfieldMan_->getTotalLength());
-    createFastIndexBitfield(tempBitfield, peer);
-    return getMissingPiece(tempBitfield);
-  } else {
-    return SharedHandle<Piece>();
-  }
+  getMissingPiece(pieces, minMissingBlocks,
+                  peer->getBitfield(), peer->getBitfieldLength());
 }
 
-static void unsetExcludedIndexes(BitfieldMan& bitfield,
-                                 const std::vector<size_t>& excludedIndexes)
-{
-  std::for_each(excludedIndexes.begin(), excludedIndexes.end(),
-                std::bind1st(std::mem_fun(&BitfieldMan::unsetBit), &bitfield));
-}
 
-SharedHandle<Piece> DefaultPieceStorage::getMissingPiece
-(const SharedHandle<Peer>& peer, const std::vector<size_t>& excludedIndexes)
+void DefaultPieceStorage::getMissingPiece
+(std::vector<SharedHandle<Piece> >& pieces,
+ size_t minMissingBlocks,
+ const SharedHandle<Peer>& peer,
+ const std::vector<size_t>& excludedIndexes)
 {
   BitfieldMan tempBitfield(bitfieldMan_->getBlockLength(),
                            bitfieldMan_->getTotalLength());
   tempBitfield.setBitfield(peer->getBitfield(), peer->getBitfieldLength());
   unsetExcludedIndexes(tempBitfield, excludedIndexes);
-  return getMissingPiece(tempBitfield);
+  getMissingPiece(pieces, minMissingBlocks,
+                  tempBitfield.getBitfield(), tempBitfield.getBitfieldLength());
 }
 
-SharedHandle<Piece> DefaultPieceStorage::getMissingFastPiece
-(const SharedHandle<Peer>& peer, const std::vector<size_t>& excludedIndexes)
+void DefaultPieceStorage::getMissingFastPiece
+(std::vector<SharedHandle<Piece> >& pieces,
+ size_t minMissingBlocks,
+ const SharedHandle<Peer>& peer)
+{
+  if(peer->isFastExtensionEnabled() && peer->countPeerAllowedIndexSet() > 0) {
+    BitfieldMan tempBitfield(bitfieldMan_->getBlockLength(),
+                             bitfieldMan_->getTotalLength());
+    createFastIndexBitfield(tempBitfield, peer);
+    getMissingPiece(pieces, minMissingBlocks,
+                    tempBitfield.getBitfield(),
+                    tempBitfield.getBitfieldLength());
+  }
+}
+
+void DefaultPieceStorage::getMissingFastPiece
+(std::vector<SharedHandle<Piece> >& pieces,
+ size_t minMissingBlocks,
+ const SharedHandle<Peer>& peer,
+ const std::vector<size_t>& excludedIndexes)
 {
   if(peer->isFastExtensionEnabled() && peer->countPeerAllowedIndexSet() > 0) {
     BitfieldMan tempBitfield(bitfieldMan_->getBlockLength(),
                              bitfieldMan_->getTotalLength());
     createFastIndexBitfield(tempBitfield, peer);
     unsetExcludedIndexes(tempBitfield, excludedIndexes);
-    return getMissingPiece(tempBitfield);
-  } else {
+    getMissingPiece(pieces, minMissingBlocks,
+                    tempBitfield.getBitfield(),
+                    tempBitfield.getBitfieldLength());
+  }
+}
+
+SharedHandle<Piece>
+DefaultPieceStorage::getMissingPiece(const SharedHandle<Peer>& peer)
+{
+  std::vector<SharedHandle<Piece> > pieces;
+  getMissingPiece(pieces, 1, peer);
+  if(pieces.empty()) {
     return SharedHandle<Piece>();
+  } else {
+    return pieces.front();
+  }
+}
+
+SharedHandle<Piece> DefaultPieceStorage::getMissingPiece
+(const SharedHandle<Peer>& peer, const std::vector<size_t>& excludedIndexes)
+{
+  std::vector<SharedHandle<Piece> > pieces;
+  getMissingPiece(pieces, 1, peer, excludedIndexes);
+  if(pieces.empty()) {
+    return SharedHandle<Piece>();
+  } else {
+    return pieces.front();
+  }
+}
+
+SharedHandle<Piece> DefaultPieceStorage::getMissingFastPiece
+(const SharedHandle<Peer>& peer)
+{
+  std::vector<SharedHandle<Piece> > pieces;
+  getMissingFastPiece(pieces, 1, peer);
+  if(pieces.empty()) {
+    return SharedHandle<Piece>();
+  } else {
+    return pieces.front();
+  }
+}
+
+SharedHandle<Piece> DefaultPieceStorage::getMissingFastPiece
+(const SharedHandle<Peer>& peer, const std::vector<size_t>& excludedIndexes)
+{
+  std::vector<SharedHandle<Piece> > pieces;
+  getMissingFastPiece(pieces, 1, peer, excludedIndexes);
+  if(pieces.empty()) {
+    return SharedHandle<Piece>();
+  } else {
+    return pieces.front();
   }
 }
 
@@ -269,10 +337,11 @@ bool DefaultPieceStorage::hasMissingUnusedPiece()
 }
 
 SharedHandle<Piece> DefaultPieceStorage::getSparseMissingUnusedPiece
-(const unsigned char* ignoreBitfield, size_t length)
+(size_t minSplitSize, const unsigned char* ignoreBitfield, size_t length)
 {
   size_t index;
-  if(bitfieldMan_->getSparseMissingUnusedIndex(index, ignoreBitfield, length)) {
+  if(bitfieldMan_->getSparseMissingUnusedIndex
+     (index, minSplitSize, ignoreBitfield, length)) {
     return checkOutPiece(index);
   } else {
     return SharedHandle<Piece>();
@@ -361,6 +430,16 @@ void DefaultPieceStorage::completePiece(const SharedHandle<Piece>& piece)
     } else {
       logger_->info(MSG_DOWNLOAD_COMPLETED);
     }
+#ifdef ENABLE_BITTORRENT
+    if(downloadContext_->hasAttribute(bittorrent::BITTORRENT)) {
+      SharedHandle<TorrentAttribute> torrentAttrs =
+        bittorrent::getTorrentAttrs(downloadContext_);
+      if(!torrentAttrs->metadata.empty()) {
+        util::executeHookByOptName(downloadContext_->getOwnerRequestGroup(),
+                                   option_, PREF_ON_BT_DOWNLOAD_COMPLETE);
+      }
+    }
+#endif // ENABLE_BITTORRENT
   }
 }
 
@@ -509,11 +588,9 @@ void DefaultPieceStorage::initStorage()
       (option_->getAsInt(PREF_BT_MAX_OPEN_FILES));
     diskAdaptor_ = multiDiskAdaptor;
   }
-#ifdef HAVE_POSIX_FALLOCATE
   if(option_->get(PREF_FILE_ALLOCATION) == V_FALLOC) {
     diskAdaptor_->enableFallocate();
   }
-#endif // HAVE_POSIX_FALLOCATE
 }
 
 void DefaultPieceStorage::setBitfield(const unsigned char* bitfield,
@@ -686,4 +763,14 @@ void DefaultPieceStorage::addPieceStats(size_t index)
   pieceStatMan_->addPieceStats(index);
 }
 
+size_t DefaultPieceStorage::getNextUsedIndex(size_t index)
+{
+  for(size_t i = index+1; i < bitfieldMan_->countBlock(); ++i) {
+    if(bitfieldMan_->isUseBitSet(i) || bitfieldMan_->isBitSet(i)) {
+      return i;
+    }
+  }
+  return bitfieldMan_->countBlock();
+}
+
 } // namespace aria2
