@@ -45,49 +45,58 @@
 #include "DownloadContext.h"
 #include "a2functional.h"
 #include "RecoverableException.h"
+#include "wallclock.h"
+#include "RequestGroupMan.h"
+#include "CheckIntegrityEntry.h"
+#include "ServerStatMan.h"
 
 namespace aria2 {
 
-FileAllocationCommand::FileAllocationCommand(int cuid, RequestGroup* requestGroup, DownloadEngine* e, const FileAllocationEntryHandle& fileAllocationEntry):
+FileAllocationCommand::FileAllocationCommand
+(cuid_t cuid, RequestGroup* requestGroup, DownloadEngine* e,
+ const SharedHandle<FileAllocationEntry>& fileAllocationEntry):
   RealtimeCommand(cuid, requestGroup, e),
-  _fileAllocationEntry(fileAllocationEntry) {}
+  fileAllocationEntry_(fileAllocationEntry) {}
 
 FileAllocationCommand::~FileAllocationCommand() {}
 
 bool FileAllocationCommand::executeInternal()
 {
-  if(_e->isHaltRequested()) {
+  if(getRequestGroup()->isHaltRequested()) {
+    getDownloadEngine()->getFileAllocationMan()->dropPickedEntry();
     return true;
   }
-  _fileAllocationEntry->allocateChunk();
-  if(_fileAllocationEntry->finished()) {
-    logger->debug(MSG_ALLOCATION_COMPLETED,
-                  _timer.difference(),
-                  util::itos(_requestGroup->getTotalLength(), true).c_str());
-    _e->_fileAllocationMan->dropPickedEntry();
-    
-    std::deque<Command*> commands;
-    try {
-      _fileAllocationEntry->prepareForNextAction(commands, _e);
-    } catch(RecoverableException& e) {
-      std::for_each(commands.begin(), commands.end(), Deleter());
-      throw;
+  fileAllocationEntry_->allocateChunk();
+  if(fileAllocationEntry_->finished()) {
+    if(getLogger()->debug()) {
+      getLogger()->debug
+        (MSG_ALLOCATION_COMPLETED,
+         timer_.difference(global::wallclock),
+         util::itos(getRequestGroup()->getTotalLength(), true).c_str());
     }
-    _e->addCommand(commands);
-    _e->setNoWait(true);
+    getDownloadEngine()->getFileAllocationMan()->dropPickedEntry();
+    
+    std::vector<Command*>* commands = new std::vector<Command*>();
+    auto_delete_container<std::vector<Command*> > commandsDel(commands);
+    fileAllocationEntry_->prepareForNextAction(*commands, getDownloadEngine());
+    getDownloadEngine()->addCommand(*commands);
+    commands->clear();
+    getDownloadEngine()->setNoWait(true);
     return true;
   } else {
-    _e->commands.push_back(this);
+    getDownloadEngine()->addCommand(this);
     return false;
   }
 }
 
 bool FileAllocationCommand::handleException(Exception& e)
 {
-  _e->_fileAllocationMan->dropPickedEntry();
-  logger->error(MSG_FILE_ALLOCATION_FAILURE, e, cuid);
-  logger->error(MSG_DOWNLOAD_NOT_COMPLETE, cuid,
-                _requestGroup->getDownloadContext()->getBasePath().c_str());
+  getDownloadEngine()->getFileAllocationMan()->dropPickedEntry();
+  getLogger()->error
+    (MSG_FILE_ALLOCATION_FAILURE, e, util::itos(getCuid()).c_str());
+  getLogger()->error
+    (MSG_DOWNLOAD_NOT_COMPLETE, util::itos(getCuid()).c_str(),
+     getRequestGroup()->getDownloadContext()->getBasePath().c_str());
   return true;
 }
 
