@@ -41,6 +41,7 @@
 #include "URISelector.h"
 #include "LogFactory.h"
 #include "wallclock.h"
+#include "a2algo.h"
 
 namespace aria2 {
 
@@ -51,12 +52,15 @@ FileEntry::FileEntry(const std::string& path,
   path_(path), uris_(uris.begin(), uris.end()), length_(length),
   offset_(offset),
   requested_(true),
-  singleHostMultiConnection_(true),
+  uniqueProtocol_(false),
+  maxConnectionPerServer_(1),
+  lastFasterReplace_(0),
   logger_(LogFactory::getInstance()) {}
 
 FileEntry::FileEntry():
   length_(0), offset_(0), requested_(false),
-  singleHostMultiConnection_(true),
+  uniqueProtocol_(false),
+  maxConnectionPerServer_(1),
   logger_(LogFactory::getInstance()) {}
 
 FileEntry::~FileEntry() {}
@@ -99,48 +103,68 @@ void FileEntry::getUris(std::vector<std::string>& uris) const
   uris.insert(uris.end(), uris_.begin(), uris_.end());
 }
 
-std::string FileEntry::selectUri(const SharedHandle<URISelector>& uriSelector)
+template<typename InputIterator, typename OutputIterator>
+static OutputIterator
+enumerateInFlightHosts
+(InputIterator first, InputIterator last, OutputIterator out)
 {
-  return uriSelector->select(this);
-}
-
-template<typename InputIterator>
-static bool inFlightHost(InputIterator first, InputIterator last,
-                         const std::string& hostname)
-{
-  // TODO redirection should be considered here. We need to parse
-  // original URI to get hostname.
+  Request r;
   for(; first != last; ++first) {
-    if((*first)->getHost() == hostname) {
-      return true;
-    }
+    r.setUri((*first)->getUri());
+    *out++ = r.getHost();
   }
-  return false;
+  return out;
 }
 
 SharedHandle<Request>
 FileEntry::getRequest
 (const SharedHandle<URISelector>& selector,
+ bool uriReuse,
+ const std::vector<std::pair<size_t, std::string> >& usedHosts,
  const std::string& referer,
  const std::string& method)
 {
   SharedHandle<Request> req;
-  if(requestPool_.empty()) {
+  Request r;
+  std::vector<std::string> inFlightHosts;
+  enumerateInFlightHosts(inFlightRequests_.begin(), inFlightRequests_.end(),
+                         std::back_inserter(inFlightHosts));
+
+  if(!requestPool_.empty()) {
+    for(std::deque<SharedHandle<Request> >::iterator i = requestPool_.begin(),
+          eoi = requestPool_.end(); i != eoi; ++i) {
+      r.setUri((*i)->getUri());
+      if(findSecond(usedHosts.begin(), usedHosts.end(), r.getHost()) !=
+         usedHosts.end()) {
+        continue;
+      }
+      if(std::count(inFlightHosts.begin(), inFlightHosts.end(), r.getHost())
+         >= static_cast<int>(maxConnectionPerServer_)) {
+      continue;
+      }
+      req = *i;
+      requestPool_.erase(i);
+      inFlightRequests_.push_back(req);
+      return req;
+    }
+  }
+
+  for(int g = 0; g < 2; ++g) {
     std::vector<std::string> pending;
+    std::vector<std::string> ignoreHost;
     while(1) {
-      std::string uri = selector->select(this);
+      std::string uri = selector->select(this, usedHosts);
       if(uri.empty()) {
-        return req;
+        break;
       }
       req.reset(new Request());
       if(req->setUri(uri)) {
-        if(!singleHostMultiConnection_) {
-          if(inFlightHost(inFlightRequests_.begin(), inFlightRequests_.end(),
-                          req->getHost())) {
-            pending.push_back(uri);
-            req.reset();
-            continue;
-          }
+        if(std::count(inFlightHosts.begin(), inFlightHosts.end(),req->getHost())
+           >= static_cast<int>(maxConnectionPerServer_)) {
+          pending.push_back(uri);
+          ignoreHost.push_back(req->getHost());
+          req.reset();
+          continue;
         }
         req->setReferer(referer);
         req->setMethod(method);
@@ -152,10 +176,28 @@ FileEntry::getRequest
       }
     }
     uris_.insert(uris_.begin(), pending.begin(), pending.end());
-  } else {
-    req = requestPool_.front();
-    requestPool_.pop_front();
-    inFlightRequests_.push_back(req);
+    // TODO UriReuse is performed only when PREF_REUSE_URI is true.
+    if(g == 0 && uriReuse && req.isNull() && uris_.size() == pending.size()) {
+      // Reuse URIs other than ones in pending
+      reuseUri(ignoreHost);
+    } else {
+      break;
+    }
+  }
+  if(req.isNull()) {
+    Request r;
+    for(std::deque<SharedHandle<Request> >::iterator i = requestPool_.begin(),
+          eoi = requestPool_.end(); i != eoi; ++i) {
+      r.setUri((*i)->getUri());
+      if(std::count(inFlightHosts.begin(), inFlightHosts.end(), r.getHost())
+         >= static_cast<int>(maxConnectionPerServer_)) {
+        continue;
+      }
+      req = *i;
+      requestPool_.erase(i);
+      inFlightRequests_.push_back(req);
+      return req;
+    }
   }
   return req;
 }
@@ -163,7 +205,9 @@ FileEntry::getRequest
 SharedHandle<Request>
 FileEntry::findFasterRequest(const SharedHandle<Request>& base)
 {
-  if(requestPool_.empty()) {
+  const int startupIdleTime = 10;
+  if(requestPool_.empty() ||
+     lastFasterReplace_.difference(global::wallclock) < startupIdleTime) {
     return SharedHandle<Request>();
   }
   const SharedHandle<PeerStat>& fastest = requestPool_.front()->getPeerStat();
@@ -172,7 +216,6 @@ FileEntry::findFasterRequest(const SharedHandle<Request>& base)
   }
   const SharedHandle<PeerStat>& basestat = base->getPeerStat();
   // TODO hard coded value. See PREF_STARTUP_IDLE_TIME
-  const int startupIdleTime = 10;
   if(basestat.isNull() ||
      (basestat->getDownloadStartTime().
       difference(global::wallclock) >= startupIdleTime &&
@@ -181,6 +224,7 @@ FileEntry::findFasterRequest(const SharedHandle<Request>& base)
     SharedHandle<Request> fastestRequest = requestPool_.front();
     requestPool_.pop_front();
     inFlightRequests_.push_back(fastestRequest);
+    lastFasterReplace_.reset();
     return fastestRequest;
   }
   return SharedHandle<Request>();
@@ -287,8 +331,14 @@ void FileEntry::extractURIResult
   uriResults_.erase(uriResults_.begin(), i);
 }
 
-void FileEntry::reuseUri(size_t num)
+void FileEntry::reuseUri(const std::vector<std::string>& ignore)
 {
+  if(logger_->debug()) {
+    for(std::vector<std::string>::const_iterator i = ignore.begin(),
+          eoi = ignore.end(); i != eoi; ++i) {
+      logger_->debug("ignore host=%s", (*i).c_str());
+    }
+  }
   std::deque<std::string> uris = spentUris_;
   std::sort(uris.begin(), uris.end());
   uris.erase(std::unique(uris.begin(), uris.end()), uris.end());
@@ -299,11 +349,29 @@ void FileEntry::reuseUri(size_t num)
   std::sort(errorUris.begin(), errorUris.end());
   errorUris.erase(std::unique(errorUris.begin(), errorUris.end()),
                   errorUris.end());
-     
+  if(logger_->debug()) {
+    for(std::vector<std::string>::const_iterator i = errorUris.begin(),
+          eoi = errorUris.end(); i != eoi; ++i) {
+      logger_->debug("error URI=%s", (*i).c_str());
+    }
+  }
   std::vector<std::string> reusableURIs;
   std::set_difference(uris.begin(), uris.end(),
                       errorUris.begin(), errorUris.end(),
                       std::back_inserter(reusableURIs));
+  std::vector<std::string>::iterator insertionPoint = reusableURIs.begin();
+  Request req;
+  for(std::vector<std::string>::iterator i = reusableURIs.begin(),
+        eoi = reusableURIs.end(); i != eoi; ++i) {
+    req.setUri(*i);
+    if(std::find(ignore.begin(), ignore.end(), req.getHost()) == ignore.end()) {
+      if(i != insertionPoint) {
+        *insertionPoint = *i;
+      }
+      ++insertionPoint;
+    }
+  }
+  reusableURIs.erase(insertionPoint, reusableURIs.end());
   size_t ininum = reusableURIs.size();
   if(logger_->debug()) {
     logger_->debug("Found %u reusable URIs", static_cast<unsigned int>(ininum));
@@ -312,19 +380,7 @@ void FileEntry::reuseUri(size_t num)
       logger_->debug("URI=%s", (*i).c_str());
     }
   }
-  // Reuse at least num URIs here to avoid to
-  // run this process repeatedly.
-  if(ininum > 0) {
-    for(size_t i = 0; i < num/ininum; ++i) {
-      uris_.insert(uris_.end(), reusableURIs.begin(), reusableURIs.end());
-    }
-    uris_.insert(uris_.end(), reusableURIs.begin(),
-                 reusableURIs.begin()+(num%ininum));
-    if(logger_->debug()) {
-      logger_->debug("Duplication complete: now %u URIs for reuse",
-                     static_cast<unsigned int>(uris_.size()));
-    }
-  }
+  uris_.insert(uris_.end(), reusableURIs.begin(), reusableURIs.end());
 }
 
 void FileEntry::releaseRuntimeResource()
