@@ -41,15 +41,15 @@
 #include "Logger.h"
 #include "DownloadContext.h"
 #include "ServerStatMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
 
 namespace aria2 {
 
-FillRequestGroupCommand::FillRequestGroupCommand(int32_t cuid,
-                                                 DownloadEngine* e,
-                                                 time_t interval):
+FillRequestGroupCommand::FillRequestGroupCommand(cuid_t cuid,
+                                                 DownloadEngine* e):
   Command(cuid),
-  _e(e),
-  _interval(interval)
+  e_(e)
 {
   setStatusRealtime();
 }
@@ -58,19 +58,19 @@ FillRequestGroupCommand::~FillRequestGroupCommand() {}
 
 bool FillRequestGroupCommand::execute()
 {
-  if(_e->isHaltRequested()) {
+  if(e_->isHaltRequested()) {
     return true;
   }
-  SharedHandle<RequestGroupMan> rgman = _e->_requestGroupMan;
+  SharedHandle<RequestGroupMan> rgman = e_->getRequestGroupMan();
   if(rgman->queueCheckRequested()) {
     try {
       // During adding RequestGroup,
       // RequestGroupMan::requestQueueCheck() might be called, so
       // first clear it here.
       rgman->clearQueueCheck();
-      rgman->fillRequestGroupFromReserver(_e);
+      rgman->fillRequestGroupFromReserver(e_);
     } catch(RecoverableException& ex) {
-      logger->error(EX_EXCEPTION_CAUGHT, ex);
+      getLogger()->error(EX_EXCEPTION_CAUGHT, ex);
       // Re-request queue check to fulfill the requests of all
       // downloads, some might come after this exception.
       rgman->requestQueueCheck();
@@ -79,7 +79,7 @@ bool FillRequestGroupCommand::execute()
       return true;
     }
   }
-  _e->addRoutineCommand(this);
+  e_->addRoutineCommand(this);
   return false;
 }
 
